.. _controller:

Install and configure the controller node
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

This section describes how to install and configure the proxy service that
handles requests for the account, container, and object services operating
on the storage nodes.

Note that installation and configuration vary by distribution.

.. toctree::
   :maxdepth: 1

   controller-install-rdo.rst
   controller-install-ubuntu.rst
   controller-install-debian.rst
